Modules
Structs
- Aggregate
Public Key - Allows for the adding/combining of multiple BLS PublicKeys.
- Aggregate
Signature - Allows for the adding/combining of multiple BLS Signatures.
- Keypair
- A helper which stores a BLS public and private key pair.
- Public
Key - A BLS public key.
- Secret
Key - A BLS secret key.
- Signature
Enums
Constants
- G1_
BYTES - The required number of bytes for a compressed G1 point
- G2_
BYTES - The required number of bytes for a compressed G2 point
- SECRET_
KEY_ BYTES - The required number of bytes for a secret key